@@ -3,7 +3,7 @@
 # @package      hubzero-expire-sessions
 # @file         expire-sessions
 # @author       Rick Kennell <kennell@purdue.edu>
-# @author	    John Rosheck <jrosheck@purdue.edu>
+# @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
 # @copyright    Copyright (c) 2005-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
@@ -26,7 +26,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.s
-
+#
 import os,pwd,sys,time,MySQLdb,signal
 
 os.chdir("/")
@@ -47,7 +47,9 @@ elif os.path.exists("/usr/bin/maxwell"):
 else:
   mwprog=""
 
-if os.path.exists("/etc/mw-www/maxwell.conf"):
+if os.path.exists("/etc/mw-client/maxwell.conf"):
+  config_file="/etc/mw-www/maxwell.conf"
+elif os.path.exists("/etc/mw-www/maxwell.conf"):
   config_file="/etc/mw-www/maxwell.conf"
 elif os.path.exists("/etc/hubzero/maxwell.conf"):
   config_file="/etc/hubzero/maxwell.conf"
@@ -94,7 +96,8 @@ def openlog(filename):
       os.dup2(sys.stdin.fileno(), devnull.fileno())
       return
     except:
-      pass
+      print(" [Unable to write to log file (%s). Exiting...] " % filename),
+      sys.exit(3)
 
 #=============================================================================
 # Log a message.
